==> vaycore-0.5.5.tar.gz: lib/vaycore.dart <==
///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-09
///

library vaycore;

import 'package:flutter/material.dart';
import 'package:vaycore/common/options.dart';
import 'package:vaycore/common/screen_adapter.dart';
import 'package:vaycore/dartin.dart';
import 'package:vaycore/utils.dart';
import 'package:vaycore/utils/app_utils.dart';

/// 初始化方法
typedef InitMethod = void Function();

/// 组件主类
class VayCore {
  /// 单例
  static VayCore _instance = new VayCore._internal();

  /// 私有构造函数
  VayCore._internal();

  /// 工厂构造函数
  factory VayCore() => _instance;

  /// 页面BuildContext对象
  BuildContext context;

  /// 配置信息
  VayCoreOptions _options;

  VayCoreOptions get options => _options;

  /// 本地持久存储
  SpUtils _pref;

  SpUtils get pref => _pref;

  /// 加载
  void load(
    dynamic rootWidget, {
    bool isDebug = false,
    VayCoreOptions options,
    InitMethod initMethod,
  }) async {
    if (options == null) {
      options = VayCoreOptions(isDebug: isDebug);
    }
    this._options = options;
    InnerWidgetsFlutterBinding.ensureInitialized();
    await _init();
    if (initMethod != null) {
      initMethod();
    }
    InnerWidgetsFlutterBinding.ensureInitialized()
      ..attachRootWidget(rootWidget)
      ..scheduleWarmUpFrame();
  }

  /// 初始化
  _init() async {
    _pref = await SpUtils.getInstance();
    await AppUtils.init();
    // 初始化需要依赖注入的模块
    if (options.modules?.isNotEmpty ?? false) {
      startDartIn(options.modules);
    }
  }

  /// 禁用跟随系统字体缩放
  ///
  /// 使用方式：
  /// ```
  /// MaterialApp(
  ///   home: core.textScaleDisable(HomePager()),
  ///   ...
  /// );
  /// ```
  Widget textScaleDisable(Widget widget) {
    return MediaQuery(
      data: MediaQueryData.fromWindow(
        WidgetsBinding.instance.window,
      ).copyWith(
        textScaleFactor: 1,
      ),
      child: widget,
    );
  }

  /// 获取国际化字符串
  String getString<F>(F ids, [List<dynamic> params]) {
    if (this.options.locale == null) {
      return "${ids.runtimeType}";
    }
    LocaleOptions<F> localeOptions = this.options.locale;
    Map<F, dynamic> value = localeOptions.getLocalizedValueById(ids);
    if (value == null || !value.containsKey(ids)) {
      return "${ids.runtimeType}";
    }
    if (params == null || params.isEmpty) {
      return value[ids];
    }
    return StringUtils.format(value[ids], params);
  }
}

VayCore core = new VayCore();

==> vaycore-0.6.0.tar.gz: lib/vaycore.dart <==
///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-09
///

library vaycore;

import 'package:flutter/material.dart';
import 'package:vaycore/common.dart';
import 'package:vaycore/dartin.dart';
import 'package:vaycore/utils.dart';

/// 初始化方法
typedef InitMethod = void Function();

/// 组件主类
class VayCore {
  /// 单例
  static VayCore _instance = new VayCore._internal();

  /// 私有构造函数
  VayCore._internal();

  /// 工厂构造函数
  factory VayCore() => _instance;

  /// 页面BuildContext对象
  BuildContext context;

  /// 配置信息
  VayCoreOptions _options;

  VayCoreOptions get options => _options;

  /// 本地持久存储
  SpUtils _pref;

  SpUtils get pref => _pref;

  /// 加载
  void load(
    dynamic rootWidget, {
    bool isDebug = false,
    VayCoreOptions options,
    InitMethod initMethod,
  }) async {
    if (options == null) {
      options = VayCoreOptions(isDebug: isDebug);
    }
    this._options = options;
    InnerWidgetsFlutterBinding.ensureInitialized();
    await _init();
    if (initMethod != null) {
      initMethod();
    }
    InnerWidgetsFlutterBinding.ensureInitialized()
      ..attachRootWidget(rootWidget)
      ..scheduleWarmUpFrame();
  }

  /// 初始化
  _init() async {
    _pref = await SpUtils.getInstance();
    await AppUtils.init();
    // 初始化需要依赖注入的模块
    if (options.modules?.isNotEmpty ?? false) {
      startDartIn(options.modules);
    }
  }

  /// 禁用跟随系统字体缩放
  ///
  /// 使用方式：
  /// ```
  /// MaterialApp(
  ///   home: core.textScaleDisable(HomePager()),
  ///   ...
  /// );
  /// ```
  Widget textScaleDisable(Widget widget) {
    return MediaQuery(
      data: MediaQueryData.fromWindow(
        WidgetsBinding.instance.window,
      ).copyWith(
        textScaleFactor: 1,
      ),
      child: widget,
    );
  }

  /// 获取国际化字符串
  String getString<F>(F ids, [List<dynamic> params]) {
    if (this.options.locale == null) {
      return "${ids.runtimeType}";
    }
    LocaleOptions<F> localeOptions = this.options.locale;
    Map<F, dynamic> value = localeOptions.getLocalizedValueById(ids);
    if (value == null || !value.containsKey(ids)) {
      return "${ids.runtimeType}";
    }
    if (params == null || params.isEmpty) {
      return value[ids];
    }
    return StringUtils.format(value[ids], params);
  }
}

VayCore core = new VayCore();
